@@ -1457,7 +1457,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "ConnectionServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
