@@ -17,6 +17,7 @@ from .connection import (
     AwsAccessRole,
     AwsCrossAccountRole,
     AwsProperties,
+    AzureProperties,
     CloudResourceProperties,
     CloudSpannerProperties,
     CloudSqlCredential,
@@ -34,6 +35,7 @@ __all__ = (
     "AwsAccessRole",
     "AwsCrossAccountRole",
     "AwsProperties",
+    "AzureProperties",
     "CloudResourceProperties",
     "CloudSpannerProperties",
     "CloudSqlCredential",
